# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import winrt.system
from winrt import _winrt_windows_gaming_input_preview

__all__ = [
    "GameControllerProviderInfo",
]

GameControllerProviderInfo = _winrt_windows_gaming_input_preview.GameControllerProviderInfo
